"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const util_1 = require("./util");
const defaultState = {
    angle: 0,
    type: 'landscape-primary'
};
const useOrientation = (initialState = defaultState) => {
    const [state, setState] = react_1.useState(initialState);
    react_1.useEffect(() => {
        let mounted = true;
        const onChange = () => {
            if (mounted) {
                const { orientation } = screen;
                if (orientation) {
                    const { angle, type } = orientation;
                    setState({ angle, type });
                }
                else if (window.orientation) {
                    setState({
                        angle: typeof window.orientation === 'number' ? window.orientation : 0,
                        type: ''
                    });
                }
                else {
                    setState(initialState);
                }
            }
        };
        util_1.on(window, 'orientationchange', onChange);
        onChange();
        return () => {
            mounted = false;
            util_1.off(window, 'orientationchange', onChange);
        };
    }, [0]);
    return state;
};
exports.default = useOrientation;
